# coding: utf-8

"""
    PSI Pinpoint

     Module containing utility classes for interacting with AWS Pinpoint.   # noqa: E501
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "psi_pinpoint"
VERSION = "0.3.1"
REQUIRES = ["awswrangler>=2.16.1", "boto3>=1.24.2", "requests==2.25.1", "typeguard==2.13.3"]

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

setup(
    name=NAME,
    version=VERSION,
    description="PSI Pinpoint",
    author="Pearson Service Insights",
    author_email="TOIOServiceWorkflowAutomation@grp.pearson.com",
    url="https://gitlab.com/pearson-io-swa/integrations",
    keywords=["Pearson", "PSI", "Pinpoint"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
     Module containing utility classes for interacting with AWS Pinpoint.   # noqa: E501
    """,
)
